import { useCallback } from "react";
import { useMaterialStore } from "../../../../../store/simulation/useMaterialStore";
import { useProductStore } from "../../../../../store/simulation/useProductStore";
import { useSelectedProduct } from "../../../../../store/simulation/useSimulationStore";
import { usePlayButtonStore } from "../../../../../store/usePlayButtonStore";

export function useSwapHandler() {
    const { addMaterial, getMaterialById, setMaterial } = useMaterialStore();
    const { getPointUuidByActionUuid } = useProductStore();
    const { selectedProduct } = useSelectedProduct();
    const { isPlaying } = usePlayButtonStore();

    const swapLogStatus = (materialUuid: string, status: string) => {
        // console.log(`${materialUuid}, ${status}`);
    }

    const handleSwap = useCallback((action: ConveyorAction, materialId?: string) => {
        if (!action || action.actionType !== 'swap' || !isPlaying || !materialId) return;

        const { material: newMaterialType } = action;
        const material = getMaterialById(materialId);
        if (!material) return;

        setMaterial(material.materialId, newMaterialType);
        swapLogStatus(material.materialId, `Swapped to ${newMaterialType}`);

    }, [addMaterial, getMaterialById, getPointUuidByActionUuid, isPlaying, setMaterial, selectedProduct.productId]);

    return {
        handleSwap,
    };
}