import { useEffect, useCallback } from "react";
import { useSpawnHandler } from "./actionHandler/useSpawnHandler";
import { useSwapHandler } from "./actionHandler/useSwapHandler";
import { useDelayHandler } from "./actionHandler/useDelayHandler";

export function useConveyorActions() {
    const { handleSpawn, clearCurrentSpawn } = useSpawnHandler();
    const { handleSwap } = useSwapHandler();
    const { handleDelay, cleanupDelay } = useDelayHandler();

    const handleDefaultAction = useCallback((action: ConveyorAction) => {
    }, []);

    const handleSpawnAction = useCallback((action: ConveyorAction) => {
        handleSpawn(action);
    }, [handleSpawn]);

    const handleSwapAction = useCallback((action: ConveyorAction, materialId?: string) => {
        handleSwap(action, materialId);
    }, [handleSwap]);

    const handleDelayAction = useCallback((action: ConveyorAction, materialId?: string) => {
        handleDelay(action, materialId);
    }, [handleDelay]);

    const handleDespawnAction = useCallback((action: ConveyorAction) => {
        console.log(`Despawning material`);
    }, []);

    const handleConveyorAction = useCallback((action: ConveyorAction, materialId?: string) => {
        if (!action) return;

        switch (action.actionType) {
            case 'default':
                handleDefaultAction(action);
                break;
            case 'spawn':
                handleSpawnAction(action);
                break;
            case 'swap':
                handleSwapAction(action, materialId);
                break;
            case 'delay':
                handleDelayAction(action, materialId);
                break;
            case 'despawn':
                handleDespawnAction(action);
                break;
            default:
                console.warn(`Unknown conveyor action type: ${action.actionType}`);
        }
    }, [handleDefaultAction, handleSpawnAction, handleSwapAction, handleDelayAction, handleDespawnAction]);

    const cleanup = useCallback(() => {
        clearCurrentSpawn();
        cleanupDelay();
    }, [clearCurrentSpawn, cleanupDelay]);

    useEffect(() => {
        return () => {
            cleanup();
        };
    }, [cleanup]);

    return {
        handleConveyorAction,
        cleanup
    };
}