import { useFrame } from '@react-three/fiber';
import React, { useEffect, useRef, useState } from 'react';
import * as THREE from 'three';
import { MaterialModel } from '../../../materials/instances/material/materialModel';

type MaterialAnimatorProps = {
    ikSolver: any;
    armBot: ArmBotStatus;
    currentPhase: string;
};

export default function MaterialAnimator({ ikSolver, armBot, currentPhase }: MaterialAnimatorProps) {
    const sphereRef = useRef<any>(null);
    const [isRendered, setIsRendered] = useState<boolean>(false);

    useEffect(() => {
        if (currentPhase === "start-to-end") {
            setIsRendered(true);
        } else {
            setIsRendered(false);
        }
    }, [currentPhase]);

    useFrame(() => {
        if (!ikSolver || !sphereRef.current) return;

        const boneTarget = ikSolver.mesh.skeleton.bones.find((b: any) => b.name === "Bone004");
        const bone = ikSolver.mesh.skeleton.bones.find((b: any) => b.name === "Effector");

        if (!boneTarget || !bone) return;

        if (currentPhase === "start-to-end") {
            // Get world positions
            const boneTargetWorldPos = new THREE.Vector3();
            const boneWorldPos = new THREE.Vector3();
            boneTarget.getWorldPosition(boneTargetWorldPos);
            bone.getWorldPosition(boneWorldPos);

            // Calculate direction
            const direction = new THREE.Vector3();
            direction.subVectors(boneWorldPos, boneTargetWorldPos).normalize();
            const downwardDirection = direction.clone().negate();
          
            const adjustedPosition = boneWorldPos.clone().addScaledVector(downwardDirection, -0.01);

            //set position
            sphereRef.current.position.copy(adjustedPosition);

            // Set rotation
            const worldQuaternion = new THREE.Quaternion();
            bone.getWorldQuaternion(worldQuaternion);
            sphereRef.current.quaternion.copy(worldQuaternion);
        }
    });

    return (
        <>
            {isRendered && (
                <MaterialModel
                    matRef={sphereRef}
                    materialType={armBot.currentAction?.materialType || 'Default material'}
                />
            )}
        </>
    );
}
